<?php
/*
* $Id: featured.php
* $Loc: /admin/
*
* Name: FeaturedProducts
* Version: 2.3.11
* Release Date: 2024-12-03
* Author: Rainer Schmied
* 	 phoenixcartaddonsaddons.com / raiwa@phoenixcartaddons.com
*
* License: Released under the GNU General Public License
*
* Comments: Author: [Rainer Schmied @raiwa]
* Author URI: [www.phoenixcartaddons.com]
* 
* CE Phoenix, E-Commerce made Easy
* https://phoenixcart.org
* 
* Copyright (c) 2021 Phoenix Cart
* 
* 
*/

  $always_valid_actions = ['new', 'edit', 'update', 'set_flag', 'insert'];
  require('includes/application_top.php');

  Guarantor::ensure_global('currencies');

  $fID = $_GET['fID'] ?? '';

  require 'includes/segments/process_action.php';

  require('includes/template_top.php');
?>

  <div class="row">
    <div class="col">
      <h1 class="display-4 mb-2"><?= HEADING_TITLE ?></h1>
    </div>
    <div class="col text-right align-self-center">
      <?=
      empty($action)
      ? $Admin->button(BUTTON_SEARCH, 'fas fa-search', 'btn-light') . '&nbsp;'
        . $Admin->button(BUTTON_NEW_FEATURED_PRODUCT, 'fas fa-plus-square', 'btn-success text-white', $Admin->link('featured.php')->retain_query_except(['fID'])->add_parameters(['action' => 'new']))
      : $Admin->button(IMAGE_CANCEL, 'fas fa-angle-left', 'btn-light mt-2', $Admin->link('featured.php')->retain_query_except(['action', 'products_name', 'products_model']))
      ?>
    </div>
  </div>
<?php
  if ( ($action == 'new') || ($action == 'edit') ) {
    $form_action = 'insert';
    if ( ($action == 'edit') && isset($fID) ) {
      $form_action = 'update';

      $product_query = $db->query(sprintf(<<<'EOSQL'
SELECT p.products_id, p.products_model, p.products_price, pd.products_name, f.expires_date
  FROM products p, products_description pd, featured f
  WHERE p.products_id = pd.products_id
    AND pd.language_id = %s
    AND p.products_id = f.products_id
    AND f.featured_id = %s
  ORDER BY pd.products_name
EOSQL
      , (int)$_SESSION['languages_id'], (int)$fID));

      $product = $product_query->fetch_assoc();
      $fInfo = new objectInfo($product);

      } else {
        $form_action = 'insert';
        $fInfo = new objectInfo([]);
      }

    if ( $action == 'new' ) {
      echo new Form('search_featured', $Admin->link('featured.php'),'get') . new Input('action', ['value' => 'new'], 'hidden');
?>
        <div class="row">
          <div class="col-sm-7">
            <div class="form-group row ml-1">
              <label for="featuredProduct" class="col-form-label col-sm-5 text-left text-sm-right"><?= TEXT_FEATURED_PRODUCT_SEARCH ?></label>
              <div class="col-sm-7"><?= new Input('products_name', ['id' => 'featuredProductSearch', 'value' => $_GET['products_name'] ?? '', 'class' => 'form-control']) ?></div>
            </div>
          </div>

          <div class="col-sm-4">
            <div class="form-group row">
              <label for="featuredModel" class="col-form-label col-sm-5 text-left text-sm-right"><?= TEXT_FEATURED_MODEL_SEARCH ?></label>
              <div class="col-sm-7"><?= new Input('products_model', ['id' => 'featuredModelSearch', 'value' => $_GET['products_model'] ?? '', 'class' => 'form-control']) ?></div>
            </div>
          </div>

          <div class="col-sm-1">
            <div class="buttonSet row">
              <?= new Button(BUTTON_SUBMIT_SEARCH, 'fas fa-search', 'btn-info') ?>
            </div>
          </div>
        </div>
      </form>
      <hr class="mt-0">
<?php
    }
    $form = new Form('new_feature', $Admin->link('featured.php')->retain_query_except(['fID'], 'post')->set_parameter('action', $form_action));
    if ('update' === $form_action) {
      $form->hide('featured_id',  (int)$_GET['fID']);
    }
    echo $form;
?>
      <div class="form-group row">
        <label for="featuredProduct" class="col-form-label col-sm-3 text-left text-sm-right"><?= TEXT_FEATURED_PRODUCT_SELECT ?></label>
        <div class="col-sm-9">
          <?php
            if (isset($fInfo->products_name)) {
              echo new Input('products_name', ['id' => 'featuredProduct', 'value' => ($fInfo->products_name . ' (' . $currencies->format($fInfo->products_price) . ')'), 'class' => 'form-control-plaintext', 'readonly' => null]);
            } else {
              echo new Select('products_id', $products_options, ['id' => 'featuredProduct', 'class' => 'form-control', 'required' => null, 'aria-required' => 'true']);
            }
            echo new Input('products_price', ['value' => (isset($fInfo->products_price) ? $fInfo->products_price : '')], 'hidden');
          ?>
        </div>
      </div>

      <div class="form-group row">
        <label for="expdate" class="col-form-label col-sm-3 text-left text-sm-right"><?= TEXT_FEATURED_EXPIRES_DATE ?></label>
        <div class="col-sm-9">
          <?= (new Input('expdate', ['min' => date('Y-m-d'), 'id' => 'expdate', 'aria-describedby' => 'pDateHelp', 'class' => 'form-control w-25', 'onfocus' => 'this.showPicker?.()'], 'date'))->default_value(substr($fInfo->expires_date?? '', 0, 10)) ?>
          <small id="pDateHelp" class="form-text text-muted">
            <?= TEXT_FEATURED_EXPIRES_DATE_HELP ?>
          </small>
        </div>
      </div>

      <div class="alert alert-info">
        <?= TEXT_FEATURED_TIP ?>
      </div>

      <?php
        echo '<div class="buttonSet row mr-2 mt-2 mb-2">';
        echo new Button(IMAGE_SAVE, 'fas fa-save', 'btn-success btn-block btn-lg');
        echo '</div>';
      ?>

    </form>

    <script>$('#expdate').datepicker({ dateFormat: 'yy-mm-dd' });</script>

  <?php
  } else {

    $featured_sql = sprintf(<<<'EOSQL'
SELECT p.products_id, p.products_model, p.products_image, pd.products_name, f.*
  FROM products p, featured f, products_description pd
  WHERE p.products_id = pd.products_id
    AND pd.language_id = %s
    AND p.products_id = f.products_id
  ORDER BY pd.products_name
EOSQL
    , (int)$_SESSION['languages_id']);
    $table_definition = [
      'columns' => [
        [
          'name' => TABLE_HEADING_PRODUCTS,
          'function' => function (&$row) {
            return $row['products_name'] . ' <small>[' . $row['products_model'] . ']</small>';
          },
        ],
        [
          'name' => TABLE_HEADING_STATUS,
          'class' => 'text-right',
          'function' => function (&$row) {
            $href = (clone $row['onclick'])->set_parameter('action', 'set_flag');
            return ($row['status'] == '1')
                 ? '<i class="fas fa-check-circle text-success"></i> <a href="' . $href->set_parameter('flag', '0')  . '"><i class="fas fa-times-circle text-muted"></i></a>'
                 : '<a href="' . $href->set_parameter('flag', '1') . '"><i class="fas fa-check-circle text-muted"></i></a> <i class="fas fa-times-circle text-danger"></i>';
          },
        ],
        [
          'name' => TABLE_HEADING_ACTION,
          'class' => 'text-right',
          'function' => function ($row) {
            return (isset($row['info']))
                 ? '<i class="fas fa-chevron-circle-right text-info"></i>'
                 : '<a href="' . $row['onclick'] . '"><i class="fas fa-info-circle text-muted"></i></a>';
          },
        ],
      ],
      'count_text' => TEXT_DISPLAY_NUMBER_OF_FEATURED,
      'page' => $_GET['page'] ?? null,
      'web_id' => 'fID',
      'db_id' => 'featured_id',
      'rows_per_page' => MAX_DISPLAY_SEARCH_RESULTS,
      'sql' => $featured_sql,
    ];

    $table_definition['split'] = new Paginator($table_definition);

    $table_definition['split']->display_table();
  }
  require('includes/template_bottom.php');
  require('includes/application_bottom.php');
?>