<?php
/*
* $Id: bm_featured.php
* $Loc: /includes/modules/boxes/
*
* Name: FeaturedProducts
* Version: 2.3.11
* Release Date: 2024-12-03
* Author: Rainer Schmied
* 	 phoenixcartaddonsaddons.com / raiwa@phoenixcartaddons.com
*
* License: Released under the GNU General Public License
*
* Comments: Author: [Rainer Schmied @raiwa]
* Author URI: [www.phoenixcartaddons.com]
* 
* CE Phoenix, E-Commerce made Easy
* https://phoenixcart.org
* 
* Copyright (c) 2021 Phoenix Cart
* 
* 
*/

  class bm_featured extends abstract_block_module {

    const CONFIG_KEY_BASE = 'MODULE_BOXES_FEATURED_';

    public function __construct() {
      parent::__construct(__FILE__);

      $this->description .= '<p>by @raiwa <u><a target="_blank" href="http://www.oscaddons.com">www.oscaddons.com</a></u></p>';
    }

    function execute() {

      $random_query = $GLOBALS['db']->query(sprintf(<<<'EOSQL'
SELECT p.products_id
  FROM products p
  LEFT JOIN featured f
    ON p.products_id = f.products_id
  WHERE p.products_status = '1'
    AND f.status = '1'
  ORDER BY p.products_id DESC
  LIMIT %s
EOSQL
      , MODULE_BOXES_FEATURED_MAX_DISPLAY_FEATURED_PRODUCTS));

      $num_rows = mysqli_num_rows($random_query);
      if (!$num_rows) {
        return;
      }

      if ($num_rows > 1) {
        $random_query->data_seek(mt_rand(0, $num_rows - 1));
      }
      $random_selection = $random_query->fetch_assoc();

      $product = product_by_id::build((int)$random_selection['products_id']);

      $box = [
        'parameters' => ['product_card.php', 'component'],
        'classes' => 'is-product bm-whats-new',
        'title' => sprintf(MODULE_BOXES_FEATURED_BOX_TITLE, $GLOBALS['Linker']->build('featured_products.php')),
        'attributes' => $product->get('data_attributes'),
      ];

      $tpl_data = [
        'group' => $this->group,
        'file' => 'box.php',
        'type' => 'component',
      ];
      include 'includes/modules/block_template.php';
    }

    protected function get_parameters() {
      return [
        'MODULE_BOXES_FEATURED_STATUS' => [
          'title' => 'Enable Featured Module',
          'value' => 'True',
          'desc' => 'Do you want to add the module to your shop?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        'MODULE_BOXES_FEATURED_CONTENT_PLACEMENT' => [
          'title' => 'Content Placement',
          'value' => 'Right Column',
          'desc' => 'Should the module be loaded in the left or right column?',
          'set_func' => "Config::select_one(['Left Column', 'Right Column'], ",
        ],
        'MODULE_BOXES_FEATURED_MAX_DISPLAY_FEATURED_PRODUCTS' => [
          'title' => 'Max Display',
          'value' => '6',
          'desc' => 'Maximum Featured Products to be display.',
        ],
        'MODULE_BOXES_FEATURED_SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '0',
          'desc' => 'Sort order of display. Lowest is displayed first.',
        ],
        'MODULE_BOXES_FEATURED_DELETE_TABLES' => [
          'title' => 'Delete auto created tables on module Remove',
          'value' => 'False',
          'desc' => 'Do you want to remove the tables that where created during installing this module?<br><i>Note: all the created data will be deleted</i>.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
      ];
    }

    function install($parameter_key = null) {
      parent::install($parameter_key);

      $GLOBALS['db']->query(<<<'EOSQL'
CREATE TABLE IF NOT EXISTS featured (
  featured_id int(11) NOT NULL auto_increment,
  products_id int(11) NOT NULL default '0',
  featured_date_added datetime default NULL,
  featured_last_modified datetime default NULL,
  expires_date datetime default NULL,
  date_status_change datetime default NULL,
  status int(1) default '1',
  PRIMARY KEY  (featured_id),
  KEY idx_products_id (products_id)
  )
DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci AUTO_INCREMENT=1 ;
EOSQL
      );

      if (mysqli_num_rows($GLOBALS['db']->query("SELECT * FROM hooks WHERE hooks_method LIKE 'featured::expire_featured'")) != 1 ) {
        $GLOBALS['db']->query(<<<'EOSQL'
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method)
VALUES ('shop', 'system', 'startApplication', '_100_expire_featured', '', 'featured::expire_featured');
EOSQL
        );
      }

    }

    function remove($parameter_key = null) {
      parent::remove($parameter_key);

      if ( defined('MODULE_BOXES_FEATURED_DELETE_TABLES') && MODULE_BOXES_FEATURED_DELETE_TABLES == 'True' ) {
        $GLOBALS['db']->query("DROP TABLE IF EXISTS featured");
        $GLOBALS['db']->query("DELETE FROM hooks WHERE hooks_method LIKE 'featured::expire_featured'");
      }

    }

  }
