<?php
/*
* $Id: cm_i_featured_products.php
* $Loc: /includes/modules/content/index/
*
* Name: FeaturedProducts
* Version: 2.3.11
* Release Date: 2024-12-03
* Author: Rainer Schmied
* 	 phoenixcartaddonsaddons.com / raiwa@phoenixcartaddons.com
*
* License: Released under the GNU General Public License
*
* Comments: Author: [Rainer Schmied @raiwa]
* Author URI: [www.phoenixcartaddons.com]
* 
* CE Phoenix, E-Commerce made Easy
* https://phoenixcart.org
* 
* Copyright (c) 2021 Phoenix Cart
* 
* 
*/

  class cm_i_featured_products extends abstract_executable_module {

    const CONFIG_KEY_BASE = 'MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_';

    public function __construct() {
      parent::__construct(__FILE__);

      $this->description .= '<p>by @raiwa <u><a target="_blank" href="http://www.oscaddons.com">www.oscaddons.com</a></u></p>';
    }

    function execute() {

      $featured_products_content = '';

      $query = sprintf(<<<'EOSQL'
SELECT m.*, %s
EOSQL
      , Product::COLUMNS);

      if (MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_SHOW_DESCRIPTION == 'True') {
        $query .= sprintf(<<<'EOSQL'
, SUBSTRING_INDEX(pd.products_description, " ", %s) AS products_description
EOSQL
      , MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_DESCRIPTION_LENGTH);

      }

      $query .= sprintf(<<<'EOSQL'
 FROM
  products_description pd
    INNER JOIN products p ON p.products_id = pd.products_id
    LEFT JOIN manufacturers m ON p.manufacturers_id = m.manufacturers_id
    LEFT JOIN specials s ON p.products_id = s.products_id
    LEFT JOIN (SELECT products_id, COUNT(*) AS attribute_count FROM products_attributes GROUP BY products_id) a ON p.products_id = a.products_id
    LEFT JOIN featured f ON p.products_id = f.products_id
 WHERE p.products_status = 1 
  AND f.status = 1
  AND pd.language_id = %d
EOSQL
      , (int)$_SESSION['languages_id']);

      if ( defined('MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_SPECIALS_ONLY') && MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_SPECIALS_ONLY == 'true' ) {
        $query .= <<<'EOSQL'
  AND s.status = '1'
EOSQL
      ;
      }
      $query .= sprintf(<<<'EOSQL'
  ORDER BY rand() DESC
  LIMIT %s
EOSQL
      , MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_CONTENT_LIMIT);

      $featured_products_query = $GLOBALS['db']->query($query);
      if (mysqli_num_rows($featured_products_query) > 0) {
        $card = [
          'show_buttons' => true,
        ];

        $tpl_data = [ 'group' => $this->group, 'file' => __FILE__ ];
        include 'includes/modules/content/cm_template.php';
      }
    }

    protected function get_parameters() {
      return [
        $this->config_key_base . 'VERSION_INSTALLED' => [
          'title' => 'Current Version',
          'value' => '2.3.9',
          'desc' => 'Version info. It is read only',
          'set_func' => 'cm_i_featured_products::readonly(',
        ],
        $this->config_key_base . 'STATUS' => [
          'title' => 'Enable Featured Products Module',
          'value' => 'True',
          'desc' => 'Do you want to enable this module?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'CONTENT_WIDTH' => [
          'title' => 'Content Container',
          'value' => 'col-sm-12 mb-4',
          'desc' => 'What container should the content be shown in? (col-*-12 = full width, col-*-6 = half width).',
        ],
        $this->config_key_base . 'SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '300',
          'desc' => 'Sort order of display. Lowest is displayed first.',
        ],
        $this->config_key_base . 'CONTENT_LIMIT' => [
          'title' => 'Number of Products',
          'value' => '6',
          'desc' => 'Maximum Number of products that should show in this module?',
        ],
        $this->config_key_base . 'SHOW_DESCRIPTION' => [
          'title' => 'Show the product description',
          'value' => 'False',
          'desc' => 'Show the product description in the Featured Products module?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'DESCRIPTION_LENGTH' => [
          'title' => 'Maximum description length',
          'value' => '25',
          'desc' => 'The number of words (to the nearest word) of the description to display in the Featured Products module',
        ],
        $this->config_key_base . 'SPECIALS_ONLY' => [
          'title' => 'Specials Only When Displaying Featured Products',
          'value' => 'False',
          'desc' => 'Set to true or false in order to display only on specials featured products.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'SHOW_BUTTON' => [
          'title' => 'Show the product MORE button',
          'value' => 'True',
          'desc' => 'Show the MORE button in the Featured Products module?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'DELETE_TABLES' => [
          'title' => 'Delete auto created tables on module Remove',
          'value' => 'False',
          'desc' => 'Do you want to remove the tables that where created during installing this module?<br><i>Note: all the created data will be deleted</i>.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
      ];
    }

    function install($parameter_key = null) {
      parent::install($parameter_key);

      $GLOBALS['db']->query(<<<'EOSQL'
CREATE TABLE IF NOT EXISTS featured (
  featured_id int(11) NOT NULL auto_increment,
  products_id int(11) NOT NULL default '0',
  featured_date_added datetime default NULL,
  featured_last_modified datetime default NULL,
  expires_date datetime default NULL,
  date_status_change datetime default NULL,
  status int(1) default '1',
  PRIMARY KEY  (featured_id),
  KEY idx_products_id (products_id)
  )
DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci AUTO_INCREMENT=1 ;
EOSQL
      );
      if (mysqli_num_rows($GLOBALS['db']->query("SELECT * FROM hooks WHERE hooks_method LIKE 'featured::expire_featured'")) != 1 ) {
        $GLOBALS['db']->query(<<<'EOSQL'
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method)
VALUES ('shop', 'system', 'startApplication', '_100_expire_featured', '', 'featured::expire_featured');
EOSQL
        );
      }

  }

    function remove($parameter_key = null) {
      parent::remove($parameter_key);

      if ( defined('MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_DELETE_TABLES') && MODULE_CONTENT_INDEX_FEATURED_PRODUCTS_DELETE_TABLES == 'True' ) {
        $GLOBALS['db']->query("DROP TABLE IF EXISTS featured");
        $GLOBALS['db']->query("DELETE FROM hooks WHERE hooks_method LIKE 'featured::expire_featured'");
      }

    }

    public static function readonly($value) {
      return $value;
    }

  }
